==> csircd-1.13.tar.gz: csircd-1.13/include/match.h <==
#ifndef __MATCH_H__
#define __MATCH_H__

int matches(const char *ma, const char *na);
int match(const char *ma, const char *na);
int mycmp(const char *str1, const char *str2);
int myncmp(const char *str1, const char *str2, int n);
char *collapse(char *pattern);

extern unsigned char tolowertab[];

#undef tolower
#define tolower(c) (tolowertab[(u_char)(c)])

extern unsigned char touppertab[];

#undef toupper
#define toupper(c) (touppertab[(u_char)(c)])

#undef isalpha
#undef isdigit
#undef isxdigit
#undef isalnum
#undef isprint
#undef isascii
#undef isgraph
#undef ispunct
#undef islower
#undef isupper
#undef isspace
#undef iscntrl

extern unsigned char char_atribs[];

#define MATCH_PRINT		0x001
#define MATCH_CNTRL		0x002
#define MATCH_ALPHA		0x004
#define MATCH_PUNCT		0x008
#define MATCH_DIGIT		0x010
#define MATCH_SPACE		0x020

#define	iscntrl(c) (char_atribs[(u_char)(c)]&MATCH_CNTRL)
#define isalpha(c) (char_atribs[(u_char)(c)]&MATCH_ALPHA)
#define isspace(c) (char_atribs[(u_char)(c)]&MATCH_SPACE)
#define islower(c) ((char_atribs[(u_char)(c)]&MATCH_ALPHA) && ((u_char)(c) > 0x5f))
#define isupper(c) ((char_atribs[(u_char)(c)]&MATCH_ALPHA) && ((u_char)(c) < 0x60))
#define isdigit(c) (char_atribs[(u_char)(c)]&MATCH_DIGIT)
#define	isxdigit(c) (isdigit(c) || 'a' <= (c) && (c) <= 'f' || \
		     'A' <= (c) && (c) <= 'F')
#define isalnum(c) (char_atribs[(u_char)(c)]&(MATCH_DIGIT|MATCH_ALPHA))
#define isprint(c) (char_atribs[(u_char)(c)]&MATCH_PRINT)
#define isascii(c) ((u_char)(c) >= 0 && (u_char)(c) <= 0x7f)
#define isgraph(c) ((char_atribs[(u_char)(c)]&MATCH_PRINT) && ((u_char)(c) != 0x32))
#define ispunct(c) (!(char_atribs[(u_char)(c)]&(MATCH_CNTRL|MATCH_ALPHA|MATCH_DIGIT)))

#endif

==> csircd-1.14.tar.gz: csircd-1.14/include/match.h <==
#ifndef __MATCH_H__
#define __MATCH_H__

int matches(const char *ma, const char *na);
int match(const char *ma, const char *na);
int mycmp(const char *str1, const char *str2);
int myncmp(const char *str1, const char *str2, int n);
char *collapse(char *pattern);

extern unsigned char tolowertab[];

#undef tolower
#define tolower(c) (tolowertab[(u_char)(c)])

extern unsigned char touppertab[];

#undef toupper
#define toupper(c) (touppertab[(u_char)(c)])

#undef isalpha
#undef isdigit
#undef isxdigit
#undef isalnum
#undef isprint
#undef isascii
#undef isgraph
#undef ispunct
#undef islower
#undef isupper
#undef isspace
#undef iscntrl

extern unsigned int char_atribs[];

#define MATCH_PRINT					0x001
#define MATCH_CNTRL					0x002
#define MATCH_ALPHA					0x004
#define MATCH_PUNCT					0x008
#define MATCH_DIGIT					0x010
#define MATCH_SPACE					0x020
#define MATCH_HOSTNAME				0x040
#define MATCH_NICKNAME				0x080
#define MATCH_NICKNAME_FIRSTCHAR	0x100
#define MATCH_USERNAME				0x200

#define	iscntrl(c) (char_atribs[(u_char)(c)]&MATCH_CNTRL)
#define isalpha(c) (char_atribs[(u_char)(c)]&MATCH_ALPHA)
#define isspace(c) (char_atribs[(u_char)(c)]&MATCH_SPACE)
#define islower(c) ((char_atribs[(u_char)(c)]&MATCH_ALPHA) && ((u_char)(c) > 0x5f))
#define isupper(c) ((char_atribs[(u_char)(c)]&MATCH_ALPHA) && ((u_char)(c) < 0x60))
#define isdigit(c) (char_atribs[(u_char)(c)]&MATCH_DIGIT)
#define	isxdigit(c) (isdigit(c) || 'a' <= (c) && (c) <= 'f' || \
		     'A' <= (c) && (c) <= 'F')
#define isalnum(c) (char_atribs[(u_char)(c)]&(MATCH_DIGIT|MATCH_ALPHA))
#define isprint(c) (char_atribs[(u_char)(c)]&MATCH_PRINT)
#define isascii(c) ((u_char)(c) >= 0 && (u_char)(c) <= 0x7f)
#define isgraph(c) ((char_atribs[(u_char)(c)]&MATCH_PRINT) && ((u_char)(c) != 0x32))
#define ispunct(c) (!(char_atribs[(u_char)(c)]&(MATCH_CNTRL|MATCH_ALPHA|MATCH_DIGIT)))

#define IsHostname(c)	(char_atribs[(u_char)(c)]&MATCH_HOSTNAME)
#define IsNickname(c)	(char_atribs[(u_char)(c)]&MATCH_NICKNAME)
#define IsNicknameFirstChar(c)	(char_atribs[(u_char)(c)]&MATCH_NICKNAME_FIRSTCHAR)
#define IsUsername(c)	(char_atribs[(u_char)(c)]&MATCH_USERNAME)

#endif
